==> zio-aws-timestreamwrite_3-5.17.161.1-sources.jar: zio/aws/timestreamwrite/model/DescribeTableResponse.scala <==
package zio.aws.timestreamwrite.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeTableResponse(
    table: Option[zio.aws.timestreamwrite.model.Table] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse = {
    import DescribeTableResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
      .builder()
      .optionallyWith(table.map(value => value.buildAwsValue()))(_.table)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.DescribeTableResponse.ReadOnly =
    zio.aws.timestreamwrite.model.DescribeTableResponse.wrap(buildAwsValue())
}
object DescribeTableResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.DescribeTableResponse =
      zio.aws.timestreamwrite.model
        .DescribeTableResponse(table.map(value => value.asEditable))
    def table: Option[zio.aws.timestreamwrite.model.Table.ReadOnly]
    def getTable
        : ZIO[Any, AwsError, zio.aws.timestreamwrite.model.Table.ReadOnly] =
      AwsError.unwrapOptionField("table", table)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
  ) extends zio.aws.timestreamwrite.model.DescribeTableResponse.ReadOnly {
    override val table: Option[zio.aws.timestreamwrite.model.Table.ReadOnly] =
      scala
        .Option(impl.table())
        .map(value => zio.aws.timestreamwrite.model.Table.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
  ): zio.aws.timestreamwrite.model.DescribeTableResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-timestreamwrite_3-5.17.162.2-sources.jar: zio/aws/timestreamwrite/model/DescribeTableResponse.scala <==
package zio.aws.timestreamwrite.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DescribeTableResponse(
    table: Optional[zio.aws.timestreamwrite.model.Table] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse = {
    import DescribeTableResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
      .builder()
      .optionallyWith(table.map(value => value.buildAwsValue()))(_.table)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.DescribeTableResponse.ReadOnly =
    zio.aws.timestreamwrite.model.DescribeTableResponse.wrap(buildAwsValue())
}
object DescribeTableResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.DescribeTableResponse =
      zio.aws.timestreamwrite.model
        .DescribeTableResponse(table.map(value => value.asEditable))
    def table: Optional[zio.aws.timestreamwrite.model.Table.ReadOnly]
    def getTable
        : ZIO[Any, AwsError, zio.aws.timestreamwrite.model.Table.ReadOnly] =
      AwsError.unwrapOptionField("table", table)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
  ) extends zio.aws.timestreamwrite.model.DescribeTableResponse.ReadOnly {
    override val table: Optional[zio.aws.timestreamwrite.model.Table.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.table())
        .map(value => zio.aws.timestreamwrite.model.Table.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.DescribeTableResponse
  ): zio.aws.timestreamwrite.model.DescribeTableResponse.ReadOnly = new Wrapper(
    impl
  )
}
